==> haskell-x509-system-1.6.6-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.6
id: x509-system-1.6.6-Hx3JmNr4PsQK7Ir4YlBIvT
key: x509-system-1.6.6-Hx3JmNr4PsQK7Ir4YlBIvT
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    System.X509 System.X509.MacOS System.X509.Unix
abi: dea9e4888995afa67486144019f95a0b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/x509-system-1.6.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/x509-system-1.6.6
hs-libraries: HSx509-system-1.6.6-Hx3JmNr4PsQK7Ir4YlBIvT
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    containers-0.5.10.2 directory-1.3.0.2 filepath-1.4.1.2
    process-1.6.1.0 pem-0.2.2-F8eKoZ8aUh0162dv1azAYf
    x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC
    x509-store-1.6.5-4pWKqWJt1ng5Umxhen4oa6
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             pem-0.2.2-F8eKoZ8aUh0162dv1azAYf=d4f1faacfc3b18597ef0d86d2b217bf5
             x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC=8743d5f25d2aa44c9bee266dde37dce6
             x509-store-1.6.5-4pWKqWJt1ng5Umxhen4oa6=e437cf68af42c7cfa58a81dd7b1ad1a1
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.6-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-system
version: 1.6.6
id: x509-system-1.6.6-Axco3IEKfs68st1GJJnquI
key: x509-system-1.6.6-Axco3IEKfs68st1GJJnquI
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    System.X509 System.X509.MacOS System.X509.Unix
abi: c1f61396576c55525136a8d0abb1cf2a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/x509-system-1.6.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/x509-system-1.6.6
hs-libraries: HSx509-system-1.6.6-Axco3IEKfs68st1GJJnquI
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    containers-0.5.10.2 directory-1.3.0.2 filepath-1.4.1.2
    process-1.6.1.0 pem-0.2.2-F8eKoZ8aUh0162dv1azAYf
    x509-1.7.2-2y9vdaROq5z255WD9u8O5y
    x509-store-1.6.5-1HH4ghRO53C4eoT2iU9XrY
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             pem-0.2.2-F8eKoZ8aUh0162dv1azAYf=d4f1faacfc3b18597ef0d86d2b217bf5
             x509-1.7.2-2y9vdaROq5z255WD9u8O5y=aab3ed0278323eee2ce14dcdbb4d0a70
             x509-store-1.6.5-1HH4ghRO53C4eoT2iU9XrY=82d02034f3c9f4f6c76984242aceca0c
haddock-interfaces: /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html: /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
